

set -ex



test -f $PREFIX/bin/cwebp
test -f $PREFIX/bin/dwebp
test -f $PREFIX/lib/libwebp.a
test -f $PREFIX/lib/libwebp.dylib
test -f $PREFIX/include/webp/decode.h
test -f $PREFIX/include/webp/encode.h
test -f $PREFIX/include/webp/types.h
dwebp examples/test.webp
exit 0
